@@ -31,7 +31,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -94,7 +96,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -157,7 +161,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -220,7 +226,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -283,7 +291,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -346,7 +356,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -409,7 +421,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -472,7 +486,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -535,7 +551,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -598,7 +616,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -661,7 +681,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -724,7 +746,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -787,7 +811,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -850,7 +876,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -913,7 +941,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -976,7 +1006,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1039,7 +1071,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1102,7 +1136,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1165,7 +1201,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1228,7 +1266,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1291,7 +1331,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1354,7 +1396,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1417,7 +1461,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1480,7 +1526,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1543,7 +1591,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1606,7 +1656,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1669,7 +1721,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1732,7 +1786,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1795,7 +1851,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1858,7 +1916,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1921,7 +1981,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -1984,7 +2046,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -2047,7 +2111,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -2110,7 +2176,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -2173,7 +2241,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
@@ -2236,7 +2306,9 @@ fn main() {
         .collect();
         let scheme_files = glob::glob(target_dir.join("*.c").to_str().unwrap()).unwrap();
         if target_arch == "wasm32" {
-            builder.flag("--sysroot=../../wasi-sysroot");
+            let wasi_sdk_path =
+                &std::env::var("WASI_SDK_DIR").expect("missing environment variable: WASI_SDK_DIR");
+            builder.flag(format!("--sysroot={}", wasi_sdk_path).as_str());
         }
         builder
             .include(internals_include_path)
